@@ -178,8 +178,8 @@ class mysql(object):
 			data=cur.fetchall() if is_query else cur.lastrowid
 		# is_query or self.conn.commit()
 		return data
-	def add(self,dicts,table=None,ignore=False):
-		'''table is optional,dicts can be list or dict'''
+	def add(self,dicts,table=None,ignore=False,duplicate=[]):
+		'''table is optional,dicts can be list or dict,duplicate should be list'''
 		if not isinstance(table,str):
 			if table is None:
 				table=self.table
@@ -194,7 +194,13 @@ class mysql(object):
 			key,value=self._split_add_dict(x)
 			values+=r'(%s),'%(value)
 		ignore='' if not ignore else 'ignore'
-		return self.execute(f''' insert {ignore} `{table}`({key}) values{values[:-1]} ''')
+		duplicate_str=''
+		if duplicate:
+			duplicate_str='on duplicate key update '
+			for x in duplicate:
+				duplicate_str+=f' `{x}`=values(`{x}`),'
+			duplicate_str=duplicate_str[:-1]
+		return self.execute(f''' insert {ignore} `{table}`({key}) values{values[:-1]} {duplicate_str}''')
 	def update(self,where,data,table=None):
 		'''where can be str or dict'''
 		table=self.table if table is None else table
